"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const command_1 = require("@salesforce/command");
const find_compile_1 = require("../../../lib/find-compile");
const less = require("less"); // Import less the old fashioned way
command_1.core.Messages.importMessagesDirectory(path_1.join(__dirname, '..', '..', '..'));
const messages = command_1.core.Messages.loadMessages('dsy-sfdx-plugins', 'less-compile');
class LessCompile extends find_compile_1.FindAndCompile {
    constructor() {
        super(...arguments);
        this.extensions = ['less'];
        this.compileFile = (filepath, filename) => {
            const self = this; // for the callback
            const fileContents = fs_1.readFileSync(filepath).toString();
            less.render(fileContents, function (error, output) {
                if (error != null) {
                    // There was an error compiling this CSS file, error out
                    self.error(new Error(`Could not compile ${filepath}\n\n${error}`));
                }
                // Save the CSS file with the same name but a different extension
                const cssFileName = filepath.replace(self.extensionPattern, '.css');
                const disclaimeredCSS = `/* Auto Generated from ${filename} - make changes there, not here */\n\n${output.css}`;
                fs_1.writeFileSync(cssFileName, disclaimeredCSS); // encodes as utf-8 by default which is good
            });
        };
    }
}
LessCompile.description = messages.getMessage('commandDescription');
LessCompile.examples = [
    '$ sfdx dsy:less:compile --path ./force-app/main/default/aura/ --recursive'
];
exports.default = LessCompile;
//# sourceMappingURL=compile.js.map