"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const path_1 = require("path");
const fs_1 = require("fs");
const command_2 = require("@salesforce/command");
command_2.core.Messages.importMessagesDirectory(path_1.join(__dirname, '..', '..'));
const messages = command_2.core.Messages.loadMessages('dsy-sfdx-plugins', 'find-and-compile');
class FindAndCompile extends command_2.SfdxCommand {
    constructor() {
        super(...arguments);
        this.findFilesByExtension = (startFolder, recursive, callback) => {
            const files = fs_1.readdirSync(startFolder);
            files.forEach((filename) => {
                const filepath = path_1.join(startFolder, filename);
                const stat = fs_1.lstatSync(filepath);
                if (stat.isDirectory() && recursive) {
                    // If the file we are looking at is a directory, and we have chosen to recurse, do so now
                    this.findFilesByExtension(filepath, recursive, callback);
                }
                else if (this.extensionPattern.test(filepath)) {
                    // If the matches the extension, do the callback
                    callback(filepath, filename);
                }
            });
        };
        this.compileFile = (filepath, filename) => {
            const self = this; // for the callback
            // This is a stub, so error if we get here
            self.error(new Error('NotImplemented: you must override compileFile'));
        };
    }
    async run() {
        // Default to the current directory
        const path = this.flags.path || '.';
        // If the folder doesn't exist, bail right now
        if (!fs_1.existsSync(path)) {
            this.error(new Error(`Folder does not exist: ${path}`));
        }
        // If our file extension(s) haven't been specified, bail right now
        if (this.extensions == null) {
            this.error(new Error('Filename extensions must be specified'));
        }
        // Set our RegExp just once
        this.extensionPattern = new RegExp('\\.(' + this.extensions.join('|') + ')$');
        // Find some files and compile them
        this.findFilesByExtension(path, this.flags.recursive, this.compileFile);
        // Return an object to be displayed with --json
        return { path };
    }
}
FindAndCompile.examples = [
    '$ sfdx dsy:sass:compile --path ./force-app/main/default/aura/ --recursive'
];
FindAndCompile.args = []; // No default args (I think)
FindAndCompile.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    path: command_1.flags.string({ char: 'p', description: messages.getMessage('pathFlagDescription') }),
    recursive: command_1.flags.boolean({ char: 'r', description: messages.getMessage('recursiveFlagDescription') })
};
// Comment this out if your command does not require an org username
// protected static requiresUsername = true;
// Comment this out if your command does not support a hub org username
// protected static supportsDevhubUsername = true;
// I think it's a good idea to restrict this command to being run in an SFDX project folder,
// though perhaps we could allow this decision to be overridden with a flag.
FindAndCompile.requiresProject = true;
exports.FindAndCompile = FindAndCompile;
//# sourceMappingURL=find-compile.js.map